@@ -59,7 +59,7 @@ and hooks in case you want to build your own NRPE Server.
 
 package Nagios::NRPE::Daemon;
 
-our $VERSION = '2.0.4';
+our $VERSION = '2.0.5';
 
 use 5.010_000;
 
@@ -154,6 +154,7 @@ sub new
     $self->{SSL_cert_file}   = delete $hash{SSL_cert_file}   || undef;
     $self->{SSL_key_file}    = delete $hash{SSL_key_file}    || undef;
     $self->{SSL_cipher_list} = delete $hash{SSL_cipher_list} || undef;
+    $self->{Timeout}         = delete $hash{Timeout}         || 1;
     $self->{commandlist}     = delete $hash{commandlist}     || {};
     $self->{callback}        = delete $hash{callback}        || sub { };
 
@@ -299,6 +300,7 @@ sub create_socket
                        Proto           => 'tcp',
                        Reuse           => 1,
                        SSL_verify_mode => 0x01,
+                       Timeout         => $self->{Timeout},
                        Type            => SOCK_STREAM
                       };
         if ($self->{SSL_cipher_list})
@@ -331,7 +333,7 @@ sub create_socket
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by the authors (see AUTHORS file).
+This software is copyright (c) 2013-2018 by the authors (see AUTHORS file).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
